"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v4.proto.resources.customer_pb2
import grpc

from .customer_service_pb2 import *

class CustomerServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetCustomer(
        self,
        request: global___GetCustomerRequest,
    ) -> google.ads.google_ads.v4.proto.resources.customer_pb2.Customer: ...
    def MutateCustomer(
        self,
        request: global___MutateCustomerRequest,
    ) -> global___MutateCustomerResponse: ...
    def ListAccessibleCustomers(
        self,
        request: global___ListAccessibleCustomersRequest,
    ) -> global___ListAccessibleCustomersResponse: ...
    def CreateCustomerClient(
        self,
        request: global___CreateCustomerClientRequest,
    ) -> global___CreateCustomerClientResponse: ...

class CustomerServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetCustomer(
        self,
        request: global___GetCustomerRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v4.proto.resources.customer_pb2.Customer: ...
    @abc.abstractmethod
    def MutateCustomer(
        self,
        request: global___MutateCustomerRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateCustomerResponse: ...
    @abc.abstractmethod
    def ListAccessibleCustomers(
        self,
        request: global___ListAccessibleCustomersRequest,
        context: grpc.ServicerContext,
    ) -> global___ListAccessibleCustomersResponse: ...
    @abc.abstractmethod
    def CreateCustomerClient(
        self,
        request: global___CreateCustomerClientRequest,
        context: grpc.ServicerContext,
    ) -> global___CreateCustomerClientResponse: ...

def add_CustomerServiceServicer_to_server(
    servicer: CustomerServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class OfflineUserDataJobFailureReasonEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _OfflineUserDataJobFailureReason(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            OfflineUserDataJobFailureReason.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = (
            OfflineUserDataJobFailureReasonEnum.OfflineUserDataJobFailureReason.V(0)
        )
        UNKNOWN = OfflineUserDataJobFailureReasonEnum.OfflineUserDataJobFailureReason.V(
            1
        )
        INSUFFICIENT_MATCHED_TRANSACTIONS = (
            OfflineUserDataJobFailureReasonEnum.OfflineUserDataJobFailureReason.V(2)
        )
        INSUFFICIENT_TRANSACTIONS = (
            OfflineUserDataJobFailureReasonEnum.OfflineUserDataJobFailureReason.V(3)
        )
    class OfflineUserDataJobFailureReason(metaclass=_OfflineUserDataJobFailureReason):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = OfflineUserDataJobFailureReasonEnum.OfflineUserDataJobFailureReason.V(
        0
    )
    UNKNOWN = OfflineUserDataJobFailureReasonEnum.OfflineUserDataJobFailureReason.V(1)
    INSUFFICIENT_MATCHED_TRANSACTIONS = (
        OfflineUserDataJobFailureReasonEnum.OfflineUserDataJobFailureReason.V(2)
    )
    INSUFFICIENT_TRANSACTIONS = (
        OfflineUserDataJobFailureReasonEnum.OfflineUserDataJobFailureReason.V(3)
    )
    def __init__(
        self,
    ) -> None: ...

global___OfflineUserDataJobFailureReasonEnum = OfflineUserDataJobFailureReasonEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class RealTimeBiddingSetting(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    OPT_IN_FIELD_NUMBER: builtins.int
    @property
    def opt_in(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    def __init__(
        self,
        *,
        opt_in: typing.Optional[google.protobuf.wrappers_pb2.BoolValue] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["opt_in", b"opt_in"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["opt_in", b"opt_in"]
    ) -> None: ...

global___RealTimeBiddingSetting = RealTimeBiddingSetting



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class SearchTermMatchTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _SearchTermMatchType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            SearchTermMatchType.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = SearchTermMatchTypeEnum.SearchTermMatchType.V(0)
        UNKNOWN = SearchTermMatchTypeEnum.SearchTermMatchType.V(1)
        BROAD = SearchTermMatchTypeEnum.SearchTermMatchType.V(2)
        EXACT = SearchTermMatchTypeEnum.SearchTermMatchType.V(3)
        PHRASE = SearchTermMatchTypeEnum.SearchTermMatchType.V(4)
        NEAR_EXACT = SearchTermMatchTypeEnum.SearchTermMatchType.V(5)
        NEAR_PHRASE = SearchTermMatchTypeEnum.SearchTermMatchType.V(6)
    class SearchTermMatchType(metaclass=_SearchTermMatchType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = SearchTermMatchTypeEnum.SearchTermMatchType.V(0)
    UNKNOWN = SearchTermMatchTypeEnum.SearchTermMatchType.V(1)
    BROAD = SearchTermMatchTypeEnum.SearchTermMatchType.V(2)
    EXACT = SearchTermMatchTypeEnum.SearchTermMatchType.V(3)
    PHRASE = SearchTermMatchTypeEnum.SearchTermMatchType.V(4)
    NEAR_EXACT = SearchTermMatchTypeEnum.SearchTermMatchType.V(5)
    NEAR_PHRASE = SearchTermMatchTypeEnum.SearchTermMatchType.V(6)
    def __init__(
        self,
    ) -> None: ...

global___SearchTermMatchTypeEnum = SearchTermMatchTypeEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class GetKeywordViewRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["resource_name", b"resource_name"]
    ) -> None: ...

global___GetKeywordViewRequest = GetKeywordViewRequest



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v5.proto.common.policy_pb2
import google.ads.google_ads.v5.proto.enums.ad_group_ad_status_pb2
import google.ads.google_ads.v5.proto.enums.ad_strength_pb2
import google.ads.google_ads.v5.proto.enums.policy_approval_status_pb2
import google.ads.google_ads.v5.proto.enums.policy_review_status_pb2
import google.ads.google_ads.v5.proto.resources.ad_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AdGroupAd(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    AD_GROUP_FIELD_NUMBER: builtins.int
    AD_FIELD_NUMBER: builtins.int
    POLICY_SUMMARY_FIELD_NUMBER: builtins.int
    AD_STRENGTH_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    status: google.ads.google_ads.v5.proto.enums.ad_group_ad_status_pb2.AdGroupAdStatusEnum.AdGroupAdStatus.V = (
        ...
    )
    ad_group: typing.Text = ...
    ad_strength: google.ads.google_ads.v5.proto.enums.ad_strength_pb2.AdStrengthEnum.AdStrength.V = (
        ...
    )
    @property
    def ad(self) -> google.ads.google_ads.v5.proto.resources.ad_pb2.Ad: ...
    @property
    def policy_summary(self) -> global___AdGroupAdPolicySummary: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        status: google.ads.google_ads.v5.proto.enums.ad_group_ad_status_pb2.AdGroupAdStatusEnum.AdGroupAdStatus.V = ...,
        ad_group: typing.Text = ...,
        ad: typing.Optional[google.ads.google_ads.v5.proto.resources.ad_pb2.Ad] = ...,
        policy_summary: typing.Optional[global___AdGroupAdPolicySummary] = ...,
        ad_strength: google.ads.google_ads.v5.proto.enums.ad_strength_pb2.AdStrengthEnum.AdStrength.V = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_ad_group",
            b"_ad_group",
            "ad",
            b"ad",
            "ad_group",
            b"ad_group",
            "policy_summary",
            b"policy_summary",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_ad_group",
            b"_ad_group",
            "ad",
            b"ad",
            "ad_group",
            b"ad_group",
            "ad_strength",
            b"ad_strength",
            "policy_summary",
            b"policy_summary",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_ad_group", b"_ad_group"]
    ) -> typing_extensions.Literal["ad_group"]: ...

global___AdGroupAd = AdGroupAd

class AdGroupAdPolicySummary(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    POLICY_TOPIC_ENTRIES_FIELD_NUMBER: builtins.int
    REVIEW_STATUS_FIELD_NUMBER: builtins.int
    APPROVAL_STATUS_FIELD_NUMBER: builtins.int
    review_status: google.ads.google_ads.v5.proto.enums.policy_review_status_pb2.PolicyReviewStatusEnum.PolicyReviewStatus.V = (
        ...
    )
    approval_status: google.ads.google_ads.v5.proto.enums.policy_approval_status_pb2.PolicyApprovalStatusEnum.PolicyApprovalStatus.V = (
        ...
    )
    @property
    def policy_topic_entries(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v5.proto.common.policy_pb2.PolicyTopicEntry
    ]: ...
    def __init__(
        self,
        *,
        policy_topic_entries: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v5.proto.common.policy_pb2.PolicyTopicEntry
            ]
        ] = ...,
        review_status: google.ads.google_ads.v5.proto.enums.policy_review_status_pb2.PolicyReviewStatusEnum.PolicyReviewStatus.V = ...,
        approval_status: google.ads.google_ads.v5.proto.enums.policy_approval_status_pb2.PolicyApprovalStatusEnum.PolicyApprovalStatus.V = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "approval_status",
            b"approval_status",
            "policy_topic_entries",
            b"policy_topic_entries",
            "review_status",
            b"review_status",
        ],
    ) -> None: ...

global___AdGroupAdPolicySummary = AdGroupAdPolicySummary



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Money(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CURRENCY_CODE_FIELD_NUMBER: builtins.int
    AMOUNT_MICROS_FIELD_NUMBER: builtins.int
    currency_code: typing.Text = ...
    amount_micros: builtins.int = ...
    def __init__(
        self,
        *,
        currency_code: typing.Text = ...,
        amount_micros: builtins.int = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_amount_micros",
            b"_amount_micros",
            "_currency_code",
            b"_currency_code",
            "amount_micros",
            b"amount_micros",
            "currency_code",
            b"currency_code",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_amount_micros",
            b"_amount_micros",
            "_currency_code",
            b"_currency_code",
            "amount_micros",
            b"amount_micros",
            "currency_code",
            b"currency_code",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_amount_micros", b"_amount_micros"],
    ) -> typing_extensions.Literal["amount_micros"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_currency_code", b"_currency_code"],
    ) -> typing_extensions.Literal["currency_code"]: ...

global___Money = Money



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CustomerClient(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    CLIENT_CUSTOMER_FIELD_NUMBER: builtins.int
    HIDDEN_FIELD_NUMBER: builtins.int
    LEVEL_FIELD_NUMBER: builtins.int
    TIME_ZONE_FIELD_NUMBER: builtins.int
    TEST_ACCOUNT_FIELD_NUMBER: builtins.int
    MANAGER_FIELD_NUMBER: builtins.int
    DESCRIPTIVE_NAME_FIELD_NUMBER: builtins.int
    CURRENCY_CODE_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    @property
    def client_customer(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def hidden(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def level(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def time_zone(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def test_account(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def manager(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def descriptive_name(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def currency_code(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def id(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        client_customer: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        hidden: typing.Optional[google.protobuf.wrappers_pb2.BoolValue] = ...,
        level: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        time_zone: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        test_account: typing.Optional[google.protobuf.wrappers_pb2.BoolValue] = ...,
        manager: typing.Optional[google.protobuf.wrappers_pb2.BoolValue] = ...,
        descriptive_name: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        currency_code: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        id: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "client_customer",
            b"client_customer",
            "currency_code",
            b"currency_code",
            "descriptive_name",
            b"descriptive_name",
            "hidden",
            b"hidden",
            "id",
            b"id",
            "level",
            b"level",
            "manager",
            b"manager",
            "test_account",
            b"test_account",
            "time_zone",
            b"time_zone",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "client_customer",
            b"client_customer",
            "currency_code",
            b"currency_code",
            "descriptive_name",
            b"descriptive_name",
            "hidden",
            b"hidden",
            "id",
            b"id",
            "level",
            b"level",
            "manager",
            b"manager",
            "resource_name",
            b"resource_name",
            "test_account",
            b"test_account",
            "time_zone",
            b"time_zone",
        ],
    ) -> None: ...

global___CustomerClient = CustomerClient



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v5.proto.resources.billing_setup_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class GetBillingSetupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["resource_name", b"resource_name"]
    ) -> None: ...

global___GetBillingSetupRequest = GetBillingSetupRequest

class MutateBillingSetupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CUSTOMER_ID_FIELD_NUMBER: builtins.int
    OPERATION_FIELD_NUMBER: builtins.int
    customer_id: typing.Text = ...
    @property
    def operation(self) -> global___BillingSetupOperation: ...
    def __init__(
        self,
        *,
        customer_id: typing.Text = ...,
        operation: typing.Optional[global___BillingSetupOperation] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["operation", b"operation"]
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "customer_id", b"customer_id", "operation", b"operation"
        ],
    ) -> None: ...

global___MutateBillingSetupRequest = MutateBillingSetupRequest

class BillingSetupOperation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CREATE_FIELD_NUMBER: builtins.int
    REMOVE_FIELD_NUMBER: builtins.int
    remove: typing.Text = ...
    @property
    def create(
        self,
    ) -> google.ads.google_ads.v5.proto.resources.billing_setup_pb2.BillingSetup: ...
    def __init__(
        self,
        *,
        create: typing.Optional[
            google.ads.google_ads.v5.proto.resources.billing_setup_pb2.BillingSetup
        ] = ...,
        remove: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "create", b"create", "operation", b"operation", "remove", b"remove"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "create", b"create", "operation", b"operation", "remove", b"remove"
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["operation", b"operation"]
    ) -> typing_extensions.Literal["create", "remove"]: ...

global___BillingSetupOperation = BillingSetupOperation

class MutateBillingSetupResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESULT_FIELD_NUMBER: builtins.int
    @property
    def result(self) -> global___MutateBillingSetupResult: ...
    def __init__(
        self,
        *,
        result: typing.Optional[global___MutateBillingSetupResult] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["result", b"result"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["result", b"result"]
    ) -> None: ...

global___MutateBillingSetupResponse = MutateBillingSetupResponse

class MutateBillingSetupResult(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["resource_name", b"resource_name"]
    ) -> None: ...

global___MutateBillingSetupResult = MutateBillingSetupResult



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v4.proto.enums.distance_bucket_pb2
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class DistanceView(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    DISTANCE_BUCKET_FIELD_NUMBER: builtins.int
    METRIC_SYSTEM_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    distance_bucket: google.ads.google_ads.v4.proto.enums.distance_bucket_pb2.DistanceBucketEnum.DistanceBucket.V = (
        ...
    )
    @property
    def metric_system(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        distance_bucket: google.ads.google_ads.v4.proto.enums.distance_bucket_pb2.DistanceBucketEnum.DistanceBucket.V = ...,
        metric_system: typing.Optional[google.protobuf.wrappers_pb2.BoolValue] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["metric_system", b"metric_system"]
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "distance_bucket",
            b"distance_bucket",
            "metric_system",
            b"metric_system",
            "resource_name",
            b"resource_name",
        ],
    ) -> None: ...

global___DistanceView = DistanceView



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.enums.asset_field_type_pb2
import google.ads.google_ads.v6.proto.enums.asset_link_status_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CampaignAsset(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    CAMPAIGN_FIELD_NUMBER: builtins.int
    ASSET_FIELD_NUMBER: builtins.int
    FIELD_TYPE_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    campaign: typing.Text = ...
    asset: typing.Text = ...
    field_type: google.ads.google_ads.v6.proto.enums.asset_field_type_pb2.AssetFieldTypeEnum.AssetFieldType.V = (
        ...
    )
    status: google.ads.google_ads.v6.proto.enums.asset_link_status_pb2.AssetLinkStatusEnum.AssetLinkStatus.V = (
        ...
    )
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        campaign: typing.Text = ...,
        asset: typing.Text = ...,
        field_type: google.ads.google_ads.v6.proto.enums.asset_field_type_pb2.AssetFieldTypeEnum.AssetFieldType.V = ...,
        status: google.ads.google_ads.v6.proto.enums.asset_link_status_pb2.AssetLinkStatusEnum.AssetLinkStatus.V = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_asset",
            b"_asset",
            "_campaign",
            b"_campaign",
            "asset",
            b"asset",
            "campaign",
            b"campaign",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_asset",
            b"_asset",
            "_campaign",
            b"_campaign",
            "asset",
            b"asset",
            "campaign",
            b"campaign",
            "field_type",
            b"field_type",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_asset", b"_asset"]
    ) -> typing_extensions.Literal["asset"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_campaign", b"_campaign"]
    ) -> typing_extensions.Literal["campaign"]: ...

global___CampaignAsset = CampaignAsset



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class FeedItemErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _FeedItemError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[FeedItemError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = FeedItemErrorEnum.FeedItemError.V(0)
        UNKNOWN = FeedItemErrorEnum.FeedItemError.V(1)
        CANNOT_CONVERT_ATTRIBUTE_VALUE_FROM_STRING = FeedItemErrorEnum.FeedItemError.V(
            2
        )
        CANNOT_OPERATE_ON_REMOVED_FEED_ITEM = FeedItemErrorEnum.FeedItemError.V(3)
        DATE_TIME_MUST_BE_IN_ACCOUNT_TIME_ZONE = FeedItemErrorEnum.FeedItemError.V(4)
        KEY_ATTRIBUTES_NOT_FOUND = FeedItemErrorEnum.FeedItemError.V(5)
        INVALID_URL = FeedItemErrorEnum.FeedItemError.V(6)
        MISSING_KEY_ATTRIBUTES = FeedItemErrorEnum.FeedItemError.V(7)
        KEY_ATTRIBUTES_NOT_UNIQUE = FeedItemErrorEnum.FeedItemError.V(8)
        CANNOT_MODIFY_KEY_ATTRIBUTE_VALUE = FeedItemErrorEnum.FeedItemError.V(9)
        SIZE_TOO_LARGE_FOR_MULTI_VALUE_ATTRIBUTE = FeedItemErrorEnum.FeedItemError.V(10)
    class FeedItemError(metaclass=_FeedItemError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = FeedItemErrorEnum.FeedItemError.V(0)
    UNKNOWN = FeedItemErrorEnum.FeedItemError.V(1)
    CANNOT_CONVERT_ATTRIBUTE_VALUE_FROM_STRING = FeedItemErrorEnum.FeedItemError.V(2)
    CANNOT_OPERATE_ON_REMOVED_FEED_ITEM = FeedItemErrorEnum.FeedItemError.V(3)
    DATE_TIME_MUST_BE_IN_ACCOUNT_TIME_ZONE = FeedItemErrorEnum.FeedItemError.V(4)
    KEY_ATTRIBUTES_NOT_FOUND = FeedItemErrorEnum.FeedItemError.V(5)
    INVALID_URL = FeedItemErrorEnum.FeedItemError.V(6)
    MISSING_KEY_ATTRIBUTES = FeedItemErrorEnum.FeedItemError.V(7)
    KEY_ATTRIBUTES_NOT_UNIQUE = FeedItemErrorEnum.FeedItemError.V(8)
    CANNOT_MODIFY_KEY_ATTRIBUTE_VALUE = FeedItemErrorEnum.FeedItemError.V(9)
    SIZE_TOO_LARGE_FOR_MULTI_VALUE_ATTRIBUTE = FeedItemErrorEnum.FeedItemError.V(10)
    def __init__(
        self,
    ) -> None: ...

global___FeedItemErrorEnum = FeedItemErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class BillingSetupErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _BillingSetupError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            BillingSetupError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = BillingSetupErrorEnum.BillingSetupError.V(0)
        UNKNOWN = BillingSetupErrorEnum.BillingSetupError.V(1)
        CANNOT_USE_EXISTING_AND_NEW_ACCOUNT = BillingSetupErrorEnum.BillingSetupError.V(
            2
        )
        CANNOT_REMOVE_STARTED_BILLING_SETUP = BillingSetupErrorEnum.BillingSetupError.V(
            3
        )
        CANNOT_CHANGE_BILLING_TO_SAME_PAYMENTS_ACCOUNT = (
            BillingSetupErrorEnum.BillingSetupError.V(4)
        )
        BILLING_SETUP_NOT_PERMITTED_FOR_CUSTOMER_STATUS = (
            BillingSetupErrorEnum.BillingSetupError.V(5)
        )
        INVALID_PAYMENTS_ACCOUNT = BillingSetupErrorEnum.BillingSetupError.V(6)
        BILLING_SETUP_NOT_PERMITTED_FOR_CUSTOMER_CATEGORY = (
            BillingSetupErrorEnum.BillingSetupError.V(7)
        )
        INVALID_START_TIME_TYPE = BillingSetupErrorEnum.BillingSetupError.V(8)
        THIRD_PARTY_ALREADY_HAS_BILLING = BillingSetupErrorEnum.BillingSetupError.V(9)
        BILLING_SETUP_IN_PROGRESS = BillingSetupErrorEnum.BillingSetupError.V(10)
        NO_SIGNUP_PERMISSION = BillingSetupErrorEnum.BillingSetupError.V(11)
        CHANGE_OF_BILL_TO_IN_PROGRESS = BillingSetupErrorEnum.BillingSetupError.V(12)
        PAYMENTS_PROFILE_NOT_FOUND = BillingSetupErrorEnum.BillingSetupError.V(13)
        PAYMENTS_ACCOUNT_NOT_FOUND = BillingSetupErrorEnum.BillingSetupError.V(14)
        PAYMENTS_PROFILE_INELIGIBLE = BillingSetupErrorEnum.BillingSetupError.V(15)
        PAYMENTS_ACCOUNT_INELIGIBLE = BillingSetupErrorEnum.BillingSetupError.V(16)
        CUSTOMER_NEEDS_INTERNAL_APPROVAL = BillingSetupErrorEnum.BillingSetupError.V(17)
        PAYMENTS_ACCOUNT_INELIGIBLE_CURRENCY_CODE_MISMATCH = (
            BillingSetupErrorEnum.BillingSetupError.V(19)
        )
    class BillingSetupError(metaclass=_BillingSetupError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = BillingSetupErrorEnum.BillingSetupError.V(0)
    UNKNOWN = BillingSetupErrorEnum.BillingSetupError.V(1)
    CANNOT_USE_EXISTING_AND_NEW_ACCOUNT = BillingSetupErrorEnum.BillingSetupError.V(2)
    CANNOT_REMOVE_STARTED_BILLING_SETUP = BillingSetupErrorEnum.BillingSetupError.V(3)
    CANNOT_CHANGE_BILLING_TO_SAME_PAYMENTS_ACCOUNT = (
        BillingSetupErrorEnum.BillingSetupError.V(4)
    )
    BILLING_SETUP_NOT_PERMITTED_FOR_CUSTOMER_STATUS = (
        BillingSetupErrorEnum.BillingSetupError.V(5)
    )
    INVALID_PAYMENTS_ACCOUNT = BillingSetupErrorEnum.BillingSetupError.V(6)
    BILLING_SETUP_NOT_PERMITTED_FOR_CUSTOMER_CATEGORY = (
        BillingSetupErrorEnum.BillingSetupError.V(7)
    )
    INVALID_START_TIME_TYPE = BillingSetupErrorEnum.BillingSetupError.V(8)
    THIRD_PARTY_ALREADY_HAS_BILLING = BillingSetupErrorEnum.BillingSetupError.V(9)
    BILLING_SETUP_IN_PROGRESS = BillingSetupErrorEnum.BillingSetupError.V(10)
    NO_SIGNUP_PERMISSION = BillingSetupErrorEnum.BillingSetupError.V(11)
    CHANGE_OF_BILL_TO_IN_PROGRESS = BillingSetupErrorEnum.BillingSetupError.V(12)
    PAYMENTS_PROFILE_NOT_FOUND = BillingSetupErrorEnum.BillingSetupError.V(13)
    PAYMENTS_ACCOUNT_NOT_FOUND = BillingSetupErrorEnum.BillingSetupError.V(14)
    PAYMENTS_PROFILE_INELIGIBLE = BillingSetupErrorEnum.BillingSetupError.V(15)
    PAYMENTS_ACCOUNT_INELIGIBLE = BillingSetupErrorEnum.BillingSetupError.V(16)
    CUSTOMER_NEEDS_INTERNAL_APPROVAL = BillingSetupErrorEnum.BillingSetupError.V(17)
    PAYMENTS_ACCOUNT_INELIGIBLE_CURRENCY_CODE_MISMATCH = (
        BillingSetupErrorEnum.BillingSetupError.V(19)
    )
    def __init__(
        self,
    ) -> None: ...

global___BillingSetupErrorEnum = BillingSetupErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CustomInterestErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _CustomInterestError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            CustomInterestError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = CustomInterestErrorEnum.CustomInterestError.V(0)
        UNKNOWN = CustomInterestErrorEnum.CustomInterestError.V(1)
        NAME_ALREADY_USED = CustomInterestErrorEnum.CustomInterestError.V(2)
        CUSTOM_INTEREST_MEMBER_ID_AND_TYPE_PARAMETER_NOT_PRESENT_IN_REMOVE = (
            CustomInterestErrorEnum.CustomInterestError.V(3)
        )
        TYPE_AND_PARAMETER_NOT_FOUND = CustomInterestErrorEnum.CustomInterestError.V(4)
        TYPE_AND_PARAMETER_ALREADY_EXISTED = (
            CustomInterestErrorEnum.CustomInterestError.V(5)
        )
        INVALID_CUSTOM_INTEREST_MEMBER_TYPE = (
            CustomInterestErrorEnum.CustomInterestError.V(6)
        )
        CANNOT_REMOVE_WHILE_IN_USE = CustomInterestErrorEnum.CustomInterestError.V(7)
        CANNOT_CHANGE_TYPE = CustomInterestErrorEnum.CustomInterestError.V(8)
    class CustomInterestError(metaclass=_CustomInterestError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = CustomInterestErrorEnum.CustomInterestError.V(0)
    UNKNOWN = CustomInterestErrorEnum.CustomInterestError.V(1)
    NAME_ALREADY_USED = CustomInterestErrorEnum.CustomInterestError.V(2)
    CUSTOM_INTEREST_MEMBER_ID_AND_TYPE_PARAMETER_NOT_PRESENT_IN_REMOVE = (
        CustomInterestErrorEnum.CustomInterestError.V(3)
    )
    TYPE_AND_PARAMETER_NOT_FOUND = CustomInterestErrorEnum.CustomInterestError.V(4)
    TYPE_AND_PARAMETER_ALREADY_EXISTED = CustomInterestErrorEnum.CustomInterestError.V(
        5
    )
    INVALID_CUSTOM_INTEREST_MEMBER_TYPE = CustomInterestErrorEnum.CustomInterestError.V(
        6
    )
    CANNOT_REMOVE_WHILE_IN_USE = CustomInterestErrorEnum.CustomInterestError.V(7)
    CANNOT_CHANGE_TYPE = CustomInterestErrorEnum.CustomInterestError.V(8)
    def __init__(
        self,
    ) -> None: ...

global___CustomInterestErrorEnum = CustomInterestErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class MediaUploadErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _MediaUploadError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MediaUploadError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = MediaUploadErrorEnum.MediaUploadError.V(0)
        UNKNOWN = MediaUploadErrorEnum.MediaUploadError.V(1)
        FILE_TOO_BIG = MediaUploadErrorEnum.MediaUploadError.V(2)
        UNPARSEABLE_IMAGE = MediaUploadErrorEnum.MediaUploadError.V(3)
        ANIMATED_IMAGE_NOT_ALLOWED = MediaUploadErrorEnum.MediaUploadError.V(4)
        FORMAT_NOT_ALLOWED = MediaUploadErrorEnum.MediaUploadError.V(5)
        EXTERNAL_URL_NOT_ALLOWED = MediaUploadErrorEnum.MediaUploadError.V(6)
        INVALID_URL_REFERENCE = MediaUploadErrorEnum.MediaUploadError.V(7)
        MISSING_PRIMARY_MEDIA_BUNDLE_ENTRY = MediaUploadErrorEnum.MediaUploadError.V(8)
    class MediaUploadError(metaclass=_MediaUploadError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = MediaUploadErrorEnum.MediaUploadError.V(0)
    UNKNOWN = MediaUploadErrorEnum.MediaUploadError.V(1)
    FILE_TOO_BIG = MediaUploadErrorEnum.MediaUploadError.V(2)
    UNPARSEABLE_IMAGE = MediaUploadErrorEnum.MediaUploadError.V(3)
    ANIMATED_IMAGE_NOT_ALLOWED = MediaUploadErrorEnum.MediaUploadError.V(4)
    FORMAT_NOT_ALLOWED = MediaUploadErrorEnum.MediaUploadError.V(5)
    EXTERNAL_URL_NOT_ALLOWED = MediaUploadErrorEnum.MediaUploadError.V(6)
    INVALID_URL_REFERENCE = MediaUploadErrorEnum.MediaUploadError.V(7)
    MISSING_PRIMARY_MEDIA_BUNDLE_ENTRY = MediaUploadErrorEnum.MediaUploadError.V(8)
    def __init__(
        self,
    ) -> None: ...

global___MediaUploadErrorEnum = MediaUploadErrorEnum
